package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````,!L!`#0```#8P@```@0`!30`(``)
M`"@`'``;``$``'`0N0``$+D!`!"Y`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0`<N0``'+D```4```````$`
M`0```-R^``#<O@(`W+X"`%@"``"@$@``!@```````0`"````Z+X``.B^`@#H
MO@(`&`$``!@!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DW+X`
M`-R^`@#<O@(`)`$``"0!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````(````&````(`````0````4
M`````P```$=.50#1WL+K2!ZY_F^5$VOHA&S9H8'KY6$````%````(`````H`
M``"@$@`(`D01(``"0`!6`'`8P@@`,`@`%1$``!`"`"@`````````2`(@"@`*
M``2$`ZA`"$5@:0"$"3Y"/)<``0`()%B`!`E@#)-X"4):`$``0``!`$()`$"`
MC,"$```0D!"#"0`(`1"`@4!`P@F`+$"8`D$`(``@!`F`E`&D#I=V0`4`````
M````!@````<````)``````````````````````````H````,````#@```!``
M```1````$@```!0````7`````````!D``````````````!H````=````'@``
M```````B````(P```"0`````````)0```"8````J`````````"P`````````
M`````"T````N````+P```#``````````-````#4`````````.0``````````
M````.@```#T````^`````````#\```!`````0@```$0```!'`````````$H`
M``!+````3````$T`````````3@``````````````````````````````````
M`$\```!0`````````%(`````````5````%8```!8````````````````````
M`````%D```!=`````````%\`````````80````````!C````9```````````
M````9@```&<```!I````:@```&T```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->O!*:WU!CL5V5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]
M]MOW`%X&I(?_`:\TZ+%(G>?.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSL/Y`"
M;7.%Q<6)!9!AF.\2`2/YI)V[DQQ"1=7L4.X1XX;YG(%][1$/NI63'%N:.P]!
M39U\I]VC:UGOEWDY\HL<#!3BG@0RI86B`O89V\WCGONA;&#JT^\.R#E`'S)B
MV^VYC?$.Z?O#PDHB??\*BA!7[=Z3'*U+X\#9<5@<*]#A(AJ?UKTM#K%S6#M`
M'\/E/RR8(M1HNN.2?"'_Y`Z*F-W";GII^HO9-5>3K01B-^/PP4/R[\C?A2!/
M5Z2;EL6YG$!0&WU?,;B"#;[:5QNS`8MOO-!+?7=OXW!J"4/6GR+'J"%B9`=^
MJ9R;8M#Z@NPL]HMK?YI\AO"6?-&?+/SN"U'Y\]O3'9!U@@U#9DL0!6RRS3RM
M.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%WQ]\D!#I+=_^2"[%F[;>J\J?R=6R
M<0`````````````````````1```````````````@````+0``````````````
M(````#P``````````````"````!0```````````````@````F0,`````````
M````$@```%P"`````````````!(```#S`@`````````````2````UP(`````
M````````$@```)H$```DP0(``````"``%P#-`0`````````````2````T`(`
M````````````$@```+T!```0%@$``````!(````F!0``0'@!`#@````2``T`
M`P0``#3!`@``````$``8`(H"`````````````!(```"U`@`````````````2
M````V@0``##!`@`$````$0`7`#8#`````````````!(```!"!0``#'0!`,`#
M```2``T`?P0``*1E`0`<`0``$@`-`*`#`````````````!(```";`@``````
M```````2````1P,`````````````$@```!($``!\T0(``````!``&``/`0``
M```````````2````700`````````````$@```(L$```@:@$`[`D``!(`#0"T
M!```H&(!`.P````2``T`<@0``'QE`0`H````$@`-`,("`````````````!(`
M``"%`@`````````````2````E@$`````````````$@```",#````````````
M`!(```"S`P``.,$"``0````A`!@`1`(`````````````$@```$L"````````
M`````!(```#E`@`````````````2````\`,``#3!`@``````$``7```#````
M`````````!(```">````1!@!```````2````R@(`````````````$@```&L#
M`````````````!(````^`@`````````````2````9`(`````````````$@``
M`+0#```XP0(`!````"$`&``=!```?-$"```````0`!@`0`,``%#!`@`$````
M$0`8`"H$``#T>`$`!````!(`#0"A`0`````````````2````;P$`````````
M````$@```,H$``"0>`$`9````!(`#0`&!0``#&D!`!0!```2``T`-`0``/AX
M`0``````$@`.`*0"`````````````!(```">!```,!L!```````2``T`\P0`
M`'@5`0``````$@`+`+X``````````````!(````5`P`````````````2````
M`@$``$S!`@`!````$0`8`-X"`````````````!(```"E!````'D!``0````1
M``\`]P,``#3!`@``````$``8`'(#`````````````!(```"*`P``````````
M```2````:@``````````````$@```!P!`````````````!(```#Q!```&&(!
M`#0````2``T`.`$`````````````$@```"4$``!\T0(``````!``&`#Y!```
MD&,!`.P!```2``T`TP``````````````$@```',"`````````````!(```"'
M```````````````2````*@(`````````````$@```*\!`````````````!(`
M``#A```````````````2````\P``````````````$@```"T!``!(P0(`!```
M`!$`&`"R`P``.,$"``0````1`!@`80$`````````````$@```.P"````````
M`````!(````1!```?-$"```````0`!@`&`4``'AH`0!\````$@`-`*\`````
M`````````!(````N`P`````````````2````F`0``"3!`@``````$``7`'P#
M`````````````!(```#0`P``0,$"``0````1`!@`2P0``/1H`0`8````$@`-
M`.L!`````````````!(```#8`0`````````````2````K0,``-@8`0!8`@``
M$@`-`#T!`````````````!(```!7`P`````````````2````3@,`````````
M````$@```/8!``!4P0(`$P```!$`&``.`P`````````````2````^@(`````
M````````$@```)("`````````````!(```#D`0`````````````2````D@,`
M````````````$@```.0$``#`9@$`N`$``!(`#0!>`P`````````````2````
M0@$`````````````$@```+P"`````````````!(```!F!```S'<!`'0````2
M``T`>```````````````$@```'\!`````````````!(````Z!```C&,!``0`
M```2``T`B`$`````````````$@```$X!``#,%P$``````!(`````;&EB<&5R
M;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A
M9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R
M;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R
M7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`
M9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P
M<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E
M;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``
M7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M
M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I
M<F]N`&QD+6QI;G5X+6%R;6AF+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?
M7V)S<U]E;F1?7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C
M=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L
M96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?
M7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS
M7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?
M8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!'3$E"0U\R+C0```````````````(``P`"``(``0````(`
M```!``$``@`"``$``@`!``$``@`"``(``0````(``0`!``$``@`"`````@`"
M``,``P`"``$``@````(``@`#``,``@`!``(``0```````0`!``$``@`!``$`
M```"`````@`!``$``@`"```````!`````0`!`````@````,````````````"
M`````@`!``$````"``$``@`$``$```````$``@`"``(````"``(``@`"``(`
M`0`"`````@`!```````!``````````$``0"\`P``$````"`````4:6D-```$
M`%@%`````````0`!`!H"```0````(````!1I:0T```,`6`4````````!``$`
M:0(``!``````````%&EI#0```@!8!0```````"#!`@`5`@``.,$"`!1/``!`
MP0(`%%@``$C!`@`43@``3,$"`!0[``!0P0(`%"\``%3!`@`48```#,`"`!8'
M```0P`(`%@4``!3``@`6&@``&,`"`!8L```<P`(`%A<``"#``@`60```),`"
M`!9=```HP`(`%D<``"S``@`680``,,`"`!9>```TP`(`%@P``#C``@`68@``
M/,`"`!94``!`P`(`%D0``$3``@`6.@``2,`"`!8V``!,P`(`%D@``%#``@`6
M$```5,`"`!8>``!8P`(`%C$``%S``@`64```8,`"`!9?``!DP`(`%F<``&C`
M`@`63```;,`"`!9:``!PP`(`%@8``'3``@`6;@``>,`"`!9;``!\P`(`%E4`
M`(#``@`6(P``A,`"`!9D``"(P`(`%A4``(S``@`6,@``D,`"`!8"``"4P`(`
M%@@``)C``@`6'P``G,`"`!8E``"@P`(`%FL``*3``@`6*@``J,`"`!89``"L
MP`(`%B0``+#``@`65P``M,`"`!8Y``"XP`(`%F,``+S``@`6(```P,`"`!9I
M``#$P`(`%E$``,C``@`6;P``S,`"`!9!``#0P`(`%F@``-3``@`6"@``V,`"
M`!8G``#<P`(`%D(``.#``@`6"P``Y,`"`!9E``#HP`(`%CP``.S``@`62P``
M\,`"`!8H``#TP`(`%C\``/C``@`630``_,`"`!9L````P0(`%DD```3!`@`6
M$@``",$"`!8/```,P0(`%BD``!#!`@`6*P``%,$"`!8A```8P0(`%A8``!S!
M`@`62@``"$`MZ7H!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y6RJ`0``QH_B&LJ,
MXFSZO.4`QH_B&LJ,XF3ZO.4`QH_B&LJ,XESZO.4`QH_B&LJ,XE3ZO.4`QH_B
M&LJ,XDSZO.4`QH_B&LJ,XD3ZO.4`QH_B&LJ,XCSZO.4`QH_B&LJ,XC3ZO.4`
MQH_B&LJ,XBSZO.4`QH_B&LJ,XB3ZO.4`QH_B&LJ,XASZO.4`QH_B&LJ,XA3Z
MO.4`QH_B&LJ,X@SZO.4`QH_B&LJ,X@3ZO.4`QH_B&LJ,XOSYO.4`QH_B&LJ,
MXO3YO.4`QH_B&LJ,XNSYO.4`QH_B&LJ,XN3YO.4`QH_B&LJ,XMSYO.4`QH_B
M&LJ,XM3YO.4`QH_B&LJ,XLSYO.4`QH_B&LJ,XL3YO.4`QH_B&LJ,XKSYO.4`
MQH_B&LJ,XK3YO.4`QH_B&LJ,XJSYO.4`QH_B&LJ,XJ3YO.4`QH_B&LJ,XISY
MO.4`QH_B&LJ,XI3YO.4`QH_B&LJ,XHSYO.4`QH_B&LJ,XH3YO.4`QH_B&LJ,
MXGSYO.4`QH_B&LJ,XG3YO.4`QH_B&LJ,XFSYO.4`QH_B&LJ,XF3YO.4`QH_B
M&LJ,XESYO.4`QH_B&LJ,XE3YO.4`QH_B&LJ,XDSYO.4`QH_B&LJ,XD3YO.4`
MQH_B&LJ,XCSYO.4`QH_B&LJ,XC3YO.4`QH_B&LJ,XBSYO.4`QH_B&LJ,XB3Y
MO.4`QH_B&LJ,XASYO.4`QH_B&LJ,XA3YO.4`QH_B&LJ,X@SYO.4`QH_B&LJ,
MX@3YO.4`QH_B&LJ,XOSXO.4`QH_B&LJ,XO3XO.4`QH_B&LJ,XNSXO.4`QH_B
M&LJ,XN3XO.4`QH_B&LJ,XMSXO.4`QH_B&LJ,XM3XO.4`QH_B&LJ,XLSXO.4`
MQH_B&LJ,XL3XO.4`QH_B&LJ,XKSXO.4`QH_B&LJ,XK3XO.4`QH_B&LJ,XJSX
MO.4`QH_B&LJ,XJ3XO.4`QH_B&LJ,XISXO.4`QH_B&LJ,XI3XO.4`QH_B&LJ,
MXHSXO.4`QH_B&LJ,XH3XO.4`QH_B&LJ,XGSXO.4`QH_B&LJ,XG3XO.4`QH_B
M&LJ,XFSXO.4`QH_B&LJ,XF3XO.4`QH_B&LJ,XESXO.4`QH_B&LJ,XE3XO.4`
MQH_B&LJ,XDSXO.4`````\$`MZ2303>(0<I_E%`"-Y1`0C>4`,)?E#""-Y10`
MC>(0$(WB#""-XAPPC>62___K[!&?Y>P!G^4!(*#AUQ<`Z^0QG^4`4-/E``!5
MX]Q!GQ4)```:8?__Z]0AG^4``%#CZ`\"Y68```K`09_E-___ZP``E.7=___K
M+5;`Y0``E.7:___K`""@X0``E.7>,]+E`C"#X]XSPN74___K%#"=Y5I;G^T%
M,(/B6FN?[9`Z!^YG>[CN!7LW[L9[M.X0^O'NWB/0Y0$@@N/>(\#E00``R@,!
MH.%*___K$$"=Y50QG^5,89_E%""=Y0#@E.5(P9_E2!&?Y0$`4N,`4*#A!`"3
MY00PH.,$P(7E#!"%Y0#@A>4$$(3""`"%Y?!?!N7T/P;E`D&$P`S`A<(#``#:
M!."1Y`0`4>$$X*SE^___&@WA@N(`P*#C`,"-Y04PH.'H#Q;E`R""XN@0G^4.
MP87G;?__Z\PPG^4`0%#B$0``"N@/%N4+___K&!"-XL@`G^4H$`#KK%"?Y0``
M4.,-```*Z`\6Y?'^_^M9___K'""=Y0`PE^4$`*#A`P!2X10``!HDT(WB\("]
MZ.@/$^5T___K`$"@X>G__^KL#Q7E``!0XP0```I'%P#K[/__ZFP`G^5L$)_E
M-/__ZQ@0C>)D`)_E#!``ZP``4./L#P7EX___"O/__^K;_O_K`0"@XQ7__^L`
M`*#A`````````````(#____/04#!`@#,%P$`1!@!`$S!`@!(P0(`8.$"`"S!
M`@"4?`$`F'P!`$QB`0!$>@$`<'L!`%3!`@#@>0$``+"@XP#@H.,$$)WD#2"@
MX00@+>4$`"WE$,"?Y03`+>4,`)_E##"?Y>O^_^M-___K]'@!`-@8`0"0>`$`
M%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!YO[_ZH2D`0`@`0``'#"?Y1P`G^4#
M,&#@!@!3XQ[_+Y$0,)_E``!3XQ[_+P$3_R_A-\$"`#3!`@``````)!"?Y20`
MG^4!$&#@01&@X:$?@>#!$+#A'O\O`1`PG^4``%/C'O\O`1/_+^$TP0(`-,$"
M```````00"WI&$"?Y0`PU.4``%/C$("]&-___^L!,*#C`##$Y1"`O>AGP0(`
M"$`MZ20`G^4`,)#E``!3XP$``!H(0+WHX/__ZA`PG^4``%/C^O__"C/_+^'X
M___JY+X"```````L/9_E\$\MZ;W?3>(`,)/E.,"`XFC@C>)X8(#B*`"-Y>PR
MC>4@8(WE\*/-X8(`G.@(P(SB$.".X@<TH.$`,(WE`82@X0`PH.,,,(WE_R@(
MX@`PH.,A1*#A^"'-X0`PH.,4,(WEV"'-X2&LH.$'3(3A`1R@X0$@@N$GO*#A
M_PP$X@`0H.,$L(WE^`'-X=``S>$'I(KA)U2@X?\(`.('?*#A`!"@XP<`@.$`
M8*#A`7"@X=@!S>$(4(WE$+"-Y0(`@.$#$('A`""@X0$PH.'_``KB`!"@XP`@
M@N$!,(/AV`#-X0`0H.,!<(?A_PP`X@!@AN$&`*#A!Q"@X=!AS>$`<*#C!Q"!
MX?]@!N(&`(#A(&"=Y?`A3N$&`%SA^`!.X<+__QIPP(WBR`"-XJ`0C>)@X(WB
MX("-XD"0H./8(.'AV$#@X=A@[.'P8,WA!&`BX`5P(^`&(*#A!S"@X=!@S>'8
M0.[A`F`FX`1@)N`#<"?@!7`GX*:OH.$&0);@AZ"*X0H@A.$"0*#A`%"@XP&0
M6>+X0.CAZ/__&BC@G>70(,[AT`+.X=B!SN$"0*#A`;"@X:(=H.$`H*#A@\*!
MX=@&S>$`P(WEH\V@X03`C>4*`)#@"Q"AX/"ES>'0H,WA@B*@X0-0H.$"H(KA
M3"N?Y?B"S>'88,[A`""2X/!!S>$`,*#CV$+-X="!SN$!,*/@!Q#%X?@@S>$&
M(*#A\(+-X08`Q.$',*#A"&`&X`EP!^`!4*#A`("@XP"0H.,'4(7A`W"@X2(Q
MH.'P@,WA`$"@X0`PC>78`,WA!D"$X0)@H.$`()WE"@"0X`<_@N$`$*'B`#"-
MY02@D.`G,:#A!;"AX`0PC>70(,WA!@"@X0<0H.'XH<WA!H^@X0"PH./09\WA
MJLV@X8LRC.$(((+A^&/-X0@PC>4"8*#AT"'-X=""S>$`<*#C`D"@X0-0H.$&
M0`3@!U`%X`(@R.$#,,GA\&/-X=B#S>'88LWAJ\V@X?@$S>$(8);@`H"$X4`J
MG^4)<*?@`Y"%X08@DN``,*#C#,"-Y0<PH^#88,WAB@*@X0!`H.,`8(;A"`"2
MX`D0H^#0(<WA`%"@XP:`D.`BP:#A\$#-X0#`C>4``)WE`)"AX@,?@.$`$(WE
M(Q&@X000C>4"3Z#AT"#-X?"$S>$`D*#CJ,V@X8DRC.$$((+A`F"@X0@PC>78
M(<WA`'"@X]A'S>$&(`+@!S`#X/ACS>'08LWAJ<V@X0S`C>4$8);@D$F?Y05P
MI^`&0)3@`%"@XP=0I>#P(,WA^$'-X=A@S>'00\WAT"#-X8@"H.$*0,3A"U#%
MX0!@AN'8`<WA!"""X04P@^$"0*#A`U"@X0`@H.,`,*#C!`"0X/`@S>$%$*'@
M*C&@X08@D.``,(WE`#"AX@-0H.$`,)WE`D"@X0L_@^$`,(WE*S&@X00PC>4*
M#Z#A`J"@X=`@S>$`,*#C`+"@XP`@@N$"`*#A`""@X]!HS>'P(,WA`!"@X]@H
MG^6+,J#A!B"2X/@!S>$$,(WE`#"@XP<PH^#X1<WAT`3-X=AAS>&D3:#ABT*$
MX08``.`'$`'@T&/-X01`C>4"8);@`W"GX-@CS>$((,+A"3##X0(`@.$#$('A
M`&"6X`$PH.$#<*?@BA*@X0`@H.,`,*#C`!"-Y?@@S>'0`,WA*#&@X0@PC>4(
M$)WE!`"`X0`@EN`)'X'A"!"-Y0`PI^(I$:#A#!"-Y0A/H.'P),WA`H"@X=@@
MS>$`,*#C`)"@XP0@@N$"`*#A`""@X]AHS>'P(,WA`!"@XP`HG^6),J#A!#"-
MY08@DN#P`\WA`#"@XP<PH^#8!<WAT&/-X:A-H.&)0H3A!@``X`<0`>#88\WA
M!$"-Y0)@EN`#<*?@V"'-X0H@PN$+,,/A`@"`X0,0@>$`8);@`3"@X0-PI^"(
M$J#A`""@XP`PH.,`$(WE^"#-X=``S>$J,:#A"#"-Y0@0G>4$`(#A`""6X`L?
M@>$`,*?B"!"-Y2L1H.$,$(WE"D^@X?@ES>$"H*#AV"#-X0`0H.,`,*#C!"""
MX0(`H.$`(*#C`+"@X]!IS>'X`\WA\"#-X2@GG^6+,J#A!#"-Y08@DN``,*#C
M!S"CX-`$S>'88\WAJDV@X8M"A.$&``#@!Q`!X-AAS>$$0(WE`F"6X`-PI^#0
M(\WA""#"X0DPP^$"`(#A`Q"!X0!@EN`!,*#A`W"GX(H2H.$`(*#C`#"@XP`0
MC>7X(,WAT`#-X2@QH.$(,(WE"!"=Y00`@.$`();@"1^!X0@0C>4`,*?B*1&@
MX0P0C>4(3Z#A\"3-X0*`H.'8(,WA`#"@XP"0H.,$((+A`@"@X0`@H./8:<WA
M\"#-X0`0H.-8)I_EB3*@X00PC>4&()+@^`'-X0`PH.,',*/@V`7-X=AAS>&H
M3:#AB4*$X08``.`'$`'@T&/-X01`C>4"8);@`W"GX-@CS>$*(,+A"S##X0(`
M@.$#$('A`&"6X`$PH.$#<*?@B!*@X0`@H.,`,*#C`!"-Y?@@S>'0`,WA*C&@
MX0@PC>4($)WE!`"`X0`@EN`+'X'A`#"GX@@0C>4K$:#A#!"-Y=!JS>$*3Z#A
M^"7-X0*@H.'8(,WA`#"@XP"PH.,$((+A`@"@X0`@H.,`$*#C\"#-X80EG^6+
M,J#A!#"-Y?`#S>$&()+@`#"@XP<PH^#0!,WAT&/-X:I-H.&+0H3A!@``X`<0
M`>#88\WA!$"-Y0)@EN`#<*?@V"'-X0@@PN$),,/A`@"`X0,0@>$`8);@`3"@
MX0-PI^"*$J#A`""@XP`PH.,`$(WE^"#-X=``S>$H,:#A"#"-Y0@0G>4$`(#A
M`""6X`D?@>$($(WE`#"GXBD1H.$,$(WE"$^@X?`DS>$"@*#AV"#-X0`PH.,`
MD*#C!"""X0(`H.$`(*#CV&K-X?`@S>$`$*#CL"2?Y8DRH.$$,(WE!B"2X/@#
MS>$`,*#C!S"CX-@%S>'88\WAJ$V@X8E"A.$&``#@!Q`!X-AAS>$$0(WE`F"6
MX`-PI^#0(\WA"B#"X0LPP^$"`(#A`Q"!X0!@EN`!,*#A`W"GX(@2H.$`(*#C
M`#"@XP`0C>7X(,WAT`#-X2HQH.$(,(WE"!"=Y00`@.$`();@"Q^!X0`PI^((
M$(WE*Q&@X=!KS>$,$(WE"D^@X?@ES>$"H*#AV"#-X0`PH.,`L*#C!"""X0(`
MH.$`(*#C`!"@X_`@S>'<(Y_EBS*@X00PC>7X`<WA!B"2X``PH.,',*/@T`3-
MX=AAS>&J3:#ABT*$X08``.`'$`'@T&/-X01`C>4"8);@`W"GX-@CS>$((,+A
M"3##X0(`@.$#$('A`&"6X`$PH.$#<*?@BA*@X0`@H.,`,*#C`!"-Y?@@S>'0
M`,WA*#&@X0@PC>4($)WE!`"`X0`@EN`)'X'A`#"GX@@0C>4I$:#A#!"-Y0A/
MH.'P),WA`H"@X=@@S>$`,*#C`)"@XP0@@N$"`*#A`""@X]AKS>'P(,WA`!"@
MXP@CG^6),J#A!#"-Y08@DN#P`\WA`#"@XP<PH^#8!<WAT&/-X:A-H.&)0H3A
M!@``X`<0`>#88\WA!$"-Y0)@EN`#<*?@V"'-X0H@PN$+,,/A`@"`X0,0@>$`
M8);@`3"@X8@2H.$#<*?@`!"-Y0`@H.,`,*#CT`#-X?@@S>$J,:#A"#"-Y0@0
MG>4$`(#A`""6X`L?@>$($(WE`#"GXBL1H.$,$(WE"D^@X?@ES>$"H*#AV"#-
MX0`PH.,`L*#C!"""X0(`H.$`(*#CT&S-X?`@S>$`$*#C-"*?Y8LRH.$$,(WE
M^`/-X08@DN``,*#C!S"CX-`$S>'88\WAJDV@X8M"A.$&``#@!Q`!X-AAS>$$
M0(WE`F"6X`-PI^#0(\WA""#"X0DPP^$"`(#A`Q"!X0!@EN`!,*#A`W"GX(H2
MH.$`(*#C`#"@XP`0C>7X(,WAT`#-X2@QH.$(,(WE"!"=Y00`@.$`();@"1^!
MX0`PI^(($(WE*1&@X0P0C>4(3Z#A\"3-X0*`H.'8(,WA`#"@XP"0H.,$((+A
M`@"@X0`@H./8;,WA\"#-X0`0H.-@(9_EB3*@X08@DN#X`<WA!#"-Y0`PH.,'
M,*/@V`7-X=AAS>&H3:#AB4*$X08``.`'$`'@T&/-X01`C>4"8);@`W"GX-@C
MS>$*(,+A"S##X0(`@.$#$('A`&"6X`$PH.$#<*?@`""@XP`PH..($J#A`!"-
MY?@@S>'0`,WA*C&@X0@PC>4($)WE!`"`X0`@EN`+'X'A"!"-Y0`PI^(K$:#A
M#!"-Y0I/H.'X)<WA`J"@X=@@S>$`,*#C`+"@XP0@@N$"`*#A`""@X]!MS>'P
M(,WA`!"@XXP@G^6+,J#A!#"-Y08@DN#P`\WA`#"@XP<PH^#0!,WAT&/-X:I-
MH.&+0H3A!@``X`<0`>#88\WA!$"-Y0)@EN`#<*?@V"'-X0@@PN$),,/A`@"`
MX0,0@>$`8);@`3"@X0-PI^"*$J#A`""@XP`PH.,`$(WE^"#-X=``S>$H,:#A
M"#"-Y0@0G>4$`(#A`@``ZD#!`@"9>8):H>O9;@`@EN`)'X'A`#"GX@@0C>4I
M$:#A#!"-Y0A/H.'P),WA`H"@X=@@S>$`,*#C`)"@XP0@@N$"`*#A`""@X]AM
MS>'P(,WA`!"@XU@@'^6),J#A!B"2X/@#S>$$,(WE`#"@XP<PH^#8!<WAV&/-
MX:A-H.&)0H3A!@``X`<0`>#88<WA!$"-Y0)@EN`#<*?@T"/-X0H@PN$+,,/A
M`@"`X0,0@>$`8);@`3"@X0-PI^"($J#A`""@XP`PH.,`$(WE^"#-X=``S>$J
M,:#A"#"-Y0@0G>4$`(#A`""6X`L?@>$($(WE`#"GXBL1H.$,$(WE"D^@X?@E
MS>$"H*#AV"#-X0`PH.,`L*#C!"""X0(`H.$`(*#CT&[-X?`@S>$`$*#C+"$?
MY8LRH.$$,(WE!B"2X/@!S>$`,*#C!S"CX-`$S>'88<WAJDV@X8M"A.$&``#@
M!Q`!X-!CS>$$0(WE`F"6X`-PI^#8(\WA""#"X0DPP^$"`(#A`Q"!X0!@EN`!
M,*#A`W"GX(H2H.$`(*#C`#"@XP`0C>7X(,WAT`#-X2@QH.$(,(WE"!"=Y00`
M@.$`();@"1^!X0`PI^(($(WE*1&@X0P0C>4(3Z#A\"3-X0*`H.'8(,WA`#"@
MXP"0H.,$((+A`@"@X0`@H./8;LWA\"#-X0`0H.,`(A_EB3*@X08@DN#P`\WA
M!#"-Y0`PH.,',*/@V`7-X=!CS>&H3:#AB4*$X08``.`'$`'@V&/-X01`C>4"
M8);@`W"GX-@AS>$+,,/A`Q"!X0H@PN$!,*#AB!*@X0`0C>4"`(#A`&"6X-``
MS>$#<*?@`""@XP`PH.,$`(#A^"#-X0`@EN`J,:#A"#"-Y0`PI^(#$*#A"#"=
MY0(`H.$+/X/A"#"-Y2LQH.$,,(WE"D^@X0*@H.'8(,WA^`7-X0``H.,`$*#C
M!"""X:H]H.'P`,WA`#"-Y0(`H.$`,*#C`""@XP"PH./0;\WA^"#-X>PB'^6+
M,J#A##"-Y08@DN``,*#C!S"CX-!$S>'88<WA`!"@XP%0!>#X`\WA`F"6X``0
MG>4#<*?@T"/-X8L2@>$`$(WE#!"=Y0@@PN$),,/AJ\V@X0!`!."J'8'A`D"$
MX0-0A>$$P(WE`""@XXK"H.$`,*#C","-Y0P0C>7X(<WAV`#-X=`@S>$$8);@
M!7"GX`(`@.$`();@*#&@X1@PC>4`,*?B`Q"@X1@PG>4"`*#A"3^#X1@PC>4I
M,:#A'#"-Y=@AS>$(3Z#A`%"@XP0@@N$`0*#C\`3-X?!`S>$`$*#C`%"@XP60
MH.$`0*#A`5"@X=AOS>'X0,WA`H"@X=A%S>'L(Q_EH#V@X0`PC>4&()+@`#"@
MXP<PH^`(0`3@V&#-X?B!S>$$@*#A`$"=Y0E0!>"'PH3A!9"@X=!#S>$`P(WE
MI\V@X0)`E.`#4*7@V"/-X03`C>6&`J#A"B#"X0@@@N$+,,/A`F"4X`DP@^$#
M<*7@T"#-X0$\C>(J0:#A`"""X0*`EN#0(,/A"T^$X2M1H.'X)<WA"@^@X0!@
MA.$`D*?B!'"%X=A%S>&4I!_E"""@X?"#S>$``*#C`)"@XP`0H.,),*#A!*":
MX`:`H.$'D*#A`+"@X_``S>$%L*O@HAV@X0!0H.,`$(WE^(7-X0L0H.'8@\WA
M!;"@X=!$S>$*`*#A!J"@X09`!.``@)C@"U`%X/"DS>$!D*G@!*"@X06PH.'8
M`,WAV$'-X0#`G>6"8J#A``#$X8/"C.$*`(#A`1#%X0"`F.``P(WE"Q"!X:/-
MH.$$P(WE`9"IX`@`H.$)$*#AT(#-X4+/C>(&@(CA"*"0X`"PH>+8`,WA^*/-
MX0"PH.,@8:#A`6^&X2%QH.$`3Z#A!("&X0:0A^'89<WA^(#-X0H`H.$(8";@
MT(#,X:I-H.&8I1_E`!"@XPJ`F.`+D*G@"*"@X0FPH.'0@\WA@4*$X8#"H.$&
M@"C@"&"@X=B!S>$$0(WE`,"-Y0J`F.`+D*G@!J"8X`"PJ>+0@,WA(F&@X0-O
MAN$$@(CA"$":X`!0J^(C<:#A`C^@X01@C>4`,(WE^$7-X0!0H.,$(*#A!3"@
MX=!`S>'8@,WA$<Z-X@9`A.$'4(7A!&"@X05PH.'0H,SA!H`HX/AAS>$(8*#A
M1(8?Y0"0H.,*@)C@"Y"IX`B@H.$)L*#AV(/-X:)-H.&#0H3A!H`HX`A@H.'0
MA,WA@L*@X01`C>4*@)C@`,"-Y0N0J>`&H)C@`+"IXM"`S>$@8:#A`6^&X02`
MB.$(0)K@(7&@X0`?H.$$8(WE`!"-Y0!0J^($`*#A!("@X060H.'00,WA^(/-
MX4;/C>(&0(3A!U"%X02`H.$%D*#AV$'-X="@S.'P@\WA"$`DX/"&'^4`D*#C
M"H"8X`N0J>`(H*#A";"@X=B%S>$`$*#C","=Y:!MH.$$@"C@@6*&X0A`H.$,
M@)K@@,*@X01@C>4`D*OB`,"-Y02@F.``L*GBT(#-X1+.C>(C<:#A!H"(X0A`
MFN`B8:#A`%"KX@-OAN$"/Z#A!&"-Y="@S.$`,(WE!""@X?!$S>'00,WA`#"@
MXQC`G>4&0(3A!U"%X02`H.$%D*#AT$/-X?B`S>$`D*#C"$`DX*2''^6B;:#A
M"H"8X`N0J>`(H*#A";"@X=B#S>&#8H;A!&"-Y02`*.`(0*#A#(":X(+"H.$`
MP(WE`)"KX@2@F.``L*GBT(#-X2#!H.$!SXSA`,"-Y0Q0H.$&@(CA2L^-X@A@
MFN``<*OBT*#,X2'!H.$$P(WE`$^@X?ACS>$&`*#AT&#-X0`0H.,PP)WE!&"&
MX05PA^'80,WA!H"@X0>0H.$(0"3@^('-X4R('^4`D*#C"H"8X`N0J>`(H*#A
M";"@X="$S>&@;:#A@6*&X02`*.`(0*#A#(":X(#"H.$$8(WE`,"-Y0"0J^($
MH)C@`+"IXM"`S>$C<:#A$\Z-X@:`B.$(0)K@(F&@X0!0J^(#;X;A`C^@X01@
MC>4`,(WE!""@X?!$S>'00,WAT*#,X0C`G>4&0(3A!U"%X02`H.$%D*#AV$'-
MX?"#S>$`D*#C"$`DX/2('^4`,*#C"H"8X`N0J>`(H*#A";"@X=B#S>&B;:#A
M@V*&X02`*.`(0*#A#(":X`"0J^*"PJ#A!*"8X`"PJ>($8(WE`,"-Y="`S>$@
MP:#A`<^,X0#`C>4,4*#A!H"(X4[/C>((8)K@`'"KXM"@S.$AP:#A!,"-Y?AC
MS>$`3Z#A!@"@X=!@S>$`$*#C&,"=Y01@AN$%<(?AT$/-X0:`H.$'D*#A"$`D
MX/B`S>&@B1_E`)"@XPJ`F.`+D*G@"*"@X0FPH.'0A,WAH&V@X8%BAN$$@"C@
M"$"@X0R`FN"`PJ#A!&"-Y0#`C>4`D*OB!*"8X`"PJ>+0@,WA(W&@X07-C>(&
M@(CA"$":X")AH.$`4*OB`V^&X0(_H.$$8(WE`#"-Y00@H.'P1,WAT$#-X="@
MS.$`,*#C!D"$X0=0A>$$@*#A!9"@X=A`S>'X@<WA`)"@XPA`).!(BA_E,,"=
MY0J`F.`+D*G@"*"@X0FPH.'8@\WAHFV@X8-BAN$$@"C@"$"@X0R`FN""PJ#A
M!&"-Y0#`C>4`D*OB!*"8X`"PJ>+0@,WA(,&@X0'/C.$`P(WE#%"@X0:`B.%2
MSXWB"&":X`!PJ^+0H,SA(<&@X03`C>4`3Z#A^&/-X08`H.'08,WA`!"@XP1@
MAN$%<(?AV$'-X0:`H.$'D*#A"$`DX/"#S>'PBA_E`)"@XPJ`F.`+D*G@"*"@
MX0FPH.&@;:#AT(3-X8%BAN$$8(WE","=Y02`*.`(0*#A#(":X(#"H.$`P(WE
M`)"KX@2@F.``L*GBT(#-X2-QH.$5SHWB!H"(X0A`FN`B8:#A`%"KX@-OAN$"
M/Z#A!&"-Y0`PC>4$(*#A\$3-X=!`S>'0H,SA`#"@XP9`A.$'4(7A!("@X060
MH.'00\WA^(#-X0"0H.,(0"3@G(L?Y1C`G>4*@)C@"Y"IX`B@H.$)L*#AV(/-
MX:)MH.&#8H;A!(`HX`A`H.$,@)K@@L*@X01@C>4`P(WE`)"KX@2@F.``L*GB
MT(#-X2#!H.$!SXSA`,"-Y0Q0H.$&@(CA5L^-X@A@FN``<*OBT*#,X2'!H.$$
MP(WE`$^@X?ACS>$&`*#AT&#-X0`0H.,PP)WE!&"&X05PA^'80,WA!H"@X0>0
MH.$(0"3@^('-X4B,'^4`D*#C"H"8X`N0J>`(H*#A";"@X="$S>&@;:#A@6*&
MX02`*.`(0*#A#(":X(#"H.$$8(WE`,"-Y0"0J^($H)C@`+"IXM"`S>$C<:#A
M%LZ-X@:`B.$(0)K@(F&@X0!0J^(#;X;A`C^@X01@C>4`,(WE!""@X?!$S>'0
M0,WAT*#,X0`PH.,&0(3A!U"%X02`H.$%D*#AV$'-X?"#S>$`D*#C"$`DX/",
M'^4(P)WE"H"8X`N0J>`(H*#A";"@X=B#S>&B;:#A@V*&X02`*.`(0*#A#(":
MX(+"H.$`P(WE!&"-Y0"0J^($H)C@`+"IXM"`S>$A<:#A6L^-X@:`B.$(0)K@
M(&&@X0!0J^(!;X;A`!^@X0`0C>4$8(WE!("@X?A%S>'00,WAT*#,X0"0H.,&
M0(3A!U"%X01@H.$%<*#AT$/-X?A@S>$`<*#C!D`DX&!MG^48P)WE"F"6X`MP
MI^`&H*#A!["@X=!DS>&H#:#AB0*`X0R@FN"(PJ#A`,"-Y00`C>4$8";@`+"K
MX@9`FN#08,WAJ1V@X0!0J^(`8(;A`7"'X1<>C>+P8,WA``"=Y2*AH.$`0)3@
M`%"EX@.OBN'X0<WA([&@X=!`P>$";Z#AV`'-X08@BN$*,(OAU*R?Y0`0H.,$
MH)K@`+"@XZ#-H.'88,WA!;"KX/@CS>$*0*#A@3*,X0M0H.'8I<WA`#"-Y3`P
MG>4"8";@`T"4X`:@*N``4*7BH3V@X0H@E.`$,(WE`#"EX@*@H.$#L*#AT"#-
MX8!BH.$(3Z#A!B""X0*@FN``L*OB*&&@X0H@H.$);X;A"S"@X02`AN$&S8WB
M*7&@X=A#S>$`D*#C\"3-X0DPH.$&D(?AV*!,X?"#S>$(0"3@((R?Y0E0)>`*
M@)C@`)"@XPN0J>`(H*#A";"@X=B!S>&B;:#A@V*&X02`*.`%D"G@!&"-Y?B!
MS>$(D)WE@H*@X0"`C>4)0)K@T(#-X02@H.$80)WE`%"KX@:`B.$$H)K@`+"E
MXB!AH.$(0)K@`%"KX@%OAN$A<:#A`!^@X0`0C>4$8(WE!("@X?A`S>'00,WA
MT*#,X3C`G>4&0(3A!U"%X01@H.$%<*#AT$/-X?AAS>$`D*#C!D`DX&AKG^4'
M4"7@"F"6X`!PH.,+<*?@!J"@X0>PH.'09,WAJ`V@X8D"@.$$8";@!7`GX(A"
MH.'P8,WA#&":X`#`G>4`<*OB#*"6X`1@@.$`L*?B(D&@X08`FN``$*OB`T^$
MX2-1H.$"/Z#A`#"-Y01`C>4`(*#A\`3-X=``S>$9SHWB`#"@XP0`@.$%$('A
M`&"@X0%PH.'8`<WAV*!,X?ACS>$&`"#@Q&J?Y0<0(>`*8);@`'"@XPMPI^`&
MH*#A!["@X=A@S>&B3:#A@T*$X0!@)N`!<"?@!$"-Y?A@S>$P<)WE@F*@X0<`
MFN``8(WET&#-X0`0J^(!L*#A"!"=Y01@AN$!H)#@`+"KX@9`FN`H8:#A`%"K
MX@EOAN$`8(WET*#,X2G!H.$$P(WE^$7-X0!0H.,%<*#A!A"@X01@H.'00,WA
M"`^@X=B#S>$`0(3A`5"%X00`H.$%$*#A!(`HX/`#S>$(`*#A!(J?Y0"0H.,*
M@)C@"Y"IX`B@H.$)L*#AILV@X="$S>&'PHSA","-Y1C`G>4`@"C@"$"@X0R`
MFN"GS:#A#,"-Y0"0J^($H)C@`+"IXMB`S>&&`J#A&LZ-X@"`B.$(0)K@(H&@
MX0./B.$`@(WE`%"KX@@0H.$C@:#A!("-Y0(/H.'P1,WA!""@X=!`S>'8H$SA
M`#"@XP%0A>$`0(3AT`/-X02`H.$%D*#A"``@X/B!S>%4B9_E`)"@XPJ`F.`+
MD*G@"*"@X0FPH.'8A<WA!1`AX*)-H.$`@"C@`9`IX(-"A.'X@,WA.)"=Y8*"
MH.$$0(WE`("-Y0D`FN``$*OBT(#-X0&PH.$($)WE!("(X0&@D.``L*OB"$":
MX`!0J^($@*#A!9"@X29!H.'0H,SA!T^$X2?!H.$`0(WE!,"-Y?B#S>$`D*#C
M!!"@X0E0H.$(0*#AT(#-X08/H.'P0,WA`("(X0&0B>'8`<WAI&V@X9A(G^4(
M`"#@"D"4X`D0(>``4*#C"U"EX/@%S>$$`*#A!1"@X0!`H.,`4*#C^$#-X="@
MS>'01,WAB\*@X0S`C>4,P)WEBV*&X:K-C.'8I<WA#,"-Y3#`G>4*0"3@"U`E
MX-"@S>'P1,WA#$"0X$#`G>4B`:#A`%"AX@,/@.$,0)3@BA*@X0*OH.$*((#A
M`%"EX@@0C>7PA,WA(Q&@X0*`B.'P0\WA`#"!X=A`S>$"`*#A"""@X=B#S>$&
M0(3AT&/-X0*`".`((*#AT(3-X1O.C>($8);@`Q"@X=A`3.$`<*?B`(`(X/`#
MS>$(`*#AL(>?Y1@PG>7X9<WA`'"@XP2`F."FK:#A`)"@XX>BBN$%D*G@`T"8
MX(8RH.$,H(WE"#"-Y0(`@.'8(,WAI[V@X0!0J>(*((+A"S"#X="@S>$`@)3@
M^"#-X2I!H.$*(*#A"*"@X0B`G>4`D*7B"*":X`LPH.$+'Z#A`+"IXM"`S.'P
MILWA`+"@XP-/A.'PH,WA(A&!X2-1H.$"#Z#A`#"=Y?B!S>$`@(3A`9"%X=`#
MS>'8I<WA!""=Y:,]H.$(0(#A@C*#X0@PC>6",J#A`""=Y?B#S>$(``#@HCV#
MX=B!S>$<,(WE!#"=Y02@"N`*0*#AHSV@X0PPC>6XII_E@C*@X1@PC>4*@)C@
MV"#-X02@@.%`P)WEV$'-X0"PH.,+D*G@#`"8X``0J>("0(3A"H"0X":AH.$'
MKXKA`)"AXB>QH.$$@)C@!@^@X0!`BN$`D*GB"E"+X=BCS>'PA,WA`)"@XP@@
MH.$),*#A!("@X060H.$$H(KAT$;-X0H`H.$'S8WB`$`$X`0`H.'80\WAV&!,
MX?@@S>$(0`3@"5`%X**MH.'X0<WA#$:?Y0!0H.,&0)3@!U"EX-A@S>'X1<WA
MV$'-X8<RH.&'HHKAICV#X=AES>$P$)WE`$"$X0%@EN#8`,WA'#"-Y0!PI^*`
M,J#A!`"6X``0I^(8,(WE`""@X0$PH.'8`<WA"@"`X0"@G>4J8:#A`*"2X`"P
MH^($,)WE"B"@X0-OAN$$,)WE(W&@X0`PG>70`,SA\*/-X0-/H.$`L*#C"S"@
MX02@AN$&L(?A"D"@X0M0H.$*8(CA^$'-X09`H.'09,WA\(3-X3C`G>4$8`;@
M!D"@X0A@H.'8@<WA`)"@XZ*MH.$(8`;@*(6?Y8.BBN$`@)C@`9"IX`8`A.'X
MA<WA`("@X=@%S>$$H(WE#`"0X``0H>*"PJ#A"$"0X`#`C>4`4*'B!("@X060
MH.'00,WA'<Z-X@I`A.'8H,WA*F&@X02@F.#80,WA"Q^@X0"PJ>(%;X;A)!&!
MX25QH.$$#Z#AV$'-X?BCS>$*@*#A`*"&X0I@H.$`D*#C!J"$X?"`S>$*`*#A
MJ*V@X="#S>$!L(?A"W"@X0"`".`(`*#A!D`$X-B`3.'P8\WA!&"@X61$G^4`
M4*#C!("8X`1`G>4%D*G@`+"@XX2BBN$`0(;AT`#-X8%BH.&@'8;A#!"-Y4`0
MG>4!8)C@T`#-X0!PJ>($@);@@!*@X0@0C>78`,WA(F&@X0-OAN$`D*?B`D^@
MX2-QH.$*`(#A"S"@X02@AN$&L(?AT&/-X0"`F.``D*GB"F"&X09`H.'88\WA
M"""@X?"$S>$$8`;@!D"@X=!CS>$*@*#A"Y"@X=``S.'X@\WA"&`&X+"#G^4`
MD*#C`("8X`&0J>`&`(3A^(7-X0"`H.'8!<WA&,"=Y:*MH.$,`)#@@Z**X0`0
MH>*"PJ#A"$"0X`R@C>4(P(WE`%"AX@2`H.$%D*#AV$#-X1[.C>(*0(3AT*#-
MX2IAH.$$H)C@T$#-X0L?H.$`L*GB!6^&X201@>$E<:#A!`^@X=A#S>'XI<WA
M"H"@X0"PH.,`H(;A"F"@X0N0H.$&H(3A\(#-X0H`H.&HK:#AT(3-X0&PA^$+
M<*#A`(`(X`@`H.$&0`3@V(!,X?AAS>$$8*#AW$*?Y0!0H.,$@)C@!$"=Y060
MJ>"$HHKA`$"&X=``S>&!8J#AH!V&X0P0C>4P$)WE`6"8X-``S>$`<*GB!("6
MX(`2H.$($(WEV`#-X2)AH.$#;X;A`)"GX@)/H.$C<:#A"@"`X0:PA^$$H(;A
MV&'-X0"`F.``D*GB"F"&X09`H.'89<WA\(3-X0"0H.,$8`;@!D"@X=AAS>$(
M(*#A"3"@X0J`H.$+D*#AT`#,X?"#S>$(8`;@*(*?Y3C`G>4`@)C@`)"@XP8`
MA.$!D*G@HJV@X0!`H.$,`)C@@Z**X0`0J>*"PJ#A!$"0X`!0H>(,H(WE","-
MY02`H.$%D*#AV$#-X1_.C>(*0(3AT*#-X2IAH.$$H)C@T$#-X0L?H.$`L*GB
M!6^&X201@>$E<:#A!`^@X?BES>'00\WA"H"@X0"PH.,`H(;A"F"@X0N0H.$&
MH(3A\(#-X0H`H.&HK:#AT(3-X0&PA^$+<*#A`(`(X`@`H.$&0`3@V(!,X?AC
MS>$$8*#A7$&?Y0!0H.,$@)C@!$"=Y060J>"$HHKA`$"&X=``S>&!8J#AH!V&
MX0P0C>48$)WE`6"8X-``S>$`<*GB!("6X(`2H.$($(WEV`#-X2)AH.$#;X;A
M`)"GX@)/H.$C<:#A!K"'X0H`@.$$H(;AV&/-X0"`F.#0`,SA"F"&X0MPA^$&
M0*#A!U"@X=AES>$`D*GB"""@X01@!N`%<`?@P$"?Y?A@S>$`0)3@V&/-X0!0
MH.,!4*7@V`#-X?B!S>$*@*#A,,"=Y0A@!N``D*#C!@"`X0DPH.$`8*#A#`"4
MX``0I>*BK:#A!F"0X(.BBN$`<*'B@L*@X0R@C>4(P(WE\&/-X=A@S>$+D*#A
M"F"&X="@S>$J0:#A"Q^@X="CS>'P@\WA!J":X-!@S>$`L*OB!T^$X281@>$G
M4:#A!@^@X?"DS>$`L*#C"F"@X0MPH.$`H(3A`;"%X0I`B.$+4(GA`@``ZJ'K
MV6[<O!N/UL%BRMB!S>$*`*#A"Q"@X02`".`%D`G@^`'-X?"`S>'0@\WA?A^-
MXC1`'^4`@`C@T`#!X0!0H.,XP)WE!`"0X`40H>"FK:#A^`#-X=``S>&'HHKA
M!*"-Y0@`@.$`0*#AV`#-X2-1H.$,`)#@`!"AX@2`D.``D*'BAL*@X0#`C>7X
M@,WAT(#-X2)!H.$#3X3A"H"(X=B@S>$"#Z#A,,"=Y0B@FN``L*OB"B"@X?BC
MS>$`H(3A!+"%X0J`H.$+D*#AV`'-X?B`S>'0A,WA"D"`X0M0@>$$@`C@!9`)
MX.A`'^7P@,WA`("@X=@`S>$"'(WB`%"@XP"`".#0`,'A`#"@XZ*MH.$$`)#@
M!1"AX(.BBN'P!,WAT`#-X02@C>4G4:#A"`"`X0!`H.'0!,WA#`"0X``0H>($
M@)#@`)"AXH+"H.$`P(WE\(/-X="`S>$F0:#A!T^$X0J`B.'0H\WA!@^@X0B@
MFN``L*OB"F"@X?"DS>$`L*#C"W"@X0"@A.$$L(7AV$#-X=B#S>$*`*#A"D"$
MX0M0A>$$@`C@!9`)X`L0H.'P@,WAV(#-X?`#S>&"'XWB`(`(X-``P>'$01_E
M`%"@XP0`D.`%$*'@IJV@X?@#S>'0`,WA&,"=Y8>BBN$(`(#A`$"@X=@#S>$$
MH(WE(U&@X0P`D.``$*'B!("0X`"0H>*&PJ#A`,"-Y?B!S>'0@,WA(D&@X0-/
MA.$*@(CAV*'-X0(/H.$(P)WE"*":X`"PJ^(*(*#A^*/-X0"@A.$$L(7A"H"@
MX0N0H.'0`\WA^('-X="$S>$*0(#A"U"!X02`".`%D`G@<$(?Y?"`S>$`@*#A
MV`'-X2$>C>(`4*#C`(`(X-``P>$`,*#CHJV@X00`D.`%$*'@@Z**X?`$S>'0
M`,WA!*"-Y2=1H.$(`(#A`$"@X=`$S>$,`)#@`!"AX@2`D.``D*'B@L*@X0#`
MC>7X@,WAT(#-X29!H.$'3X3A"H"(X=B@S>$&#Z#A"*":X`"PJ^(*8*#A\*3-
MX0"PH.,+<*#A`*"$X02PA>'80<WAV(/-X0H`H.$*0(3A"U"%X02`".`%D`G@
M"Q"@X?"`S>'8@<WA^`/-X88?C>(`@`C@T`#!X4Q#'^4`4*#C!`"0X`40H>"F
MK:#A^`#-X=``S>&'HHKA!*"-Y0@`@.$`0*#AV`#-X3#`G>4C4:#A#`"0X``0
MH>($@)#@`)"AXH;"H.$`P(WE^(#-X="`S>$B0:#A`T^$X0J`B.'8H,WA`@^@
MX1C`G>4(H)K@`+"KX@H@H.'PH\WA`*"$X02PA>$*@*#A"Y"@X=@#S>'X@,WA
MT(3-X0I`@.$+4('A!(`(X`60">#X0Q_E\(#-X0"`H.'8`,WA(AZ-X@!0H.,`
M@`C@T`#!X0`PH..BK:#A!`"0X`40H>"#HHKA\`3-X=``S>$$H(WE)U&@X0@`
M@.$`0*#AT`3-X0P`D.``$*'B!("0X`"0H>*"PJ#A`,"-Y?B!S>'0@,WA)D&@
MX0=/A.$*@(CAV*'-X08/H.$XP)WE"*":X`"PJ^(*8*#A\*3-X0"PH.,+<*#A
M`*"$X02PA>'80,WAT(/-X0H`H.$*0(3A"U"%X02`".`%D`G@"Q"@X?"`S>'8
M@,WA\`/-X8H?C>(`@`C@T`#!X=A$'^4`4*#C!`"0X`40H>"FK:#A^`'-X=``
MS>&'HHKA!*"-Y0@`@.$`0*#AV`'-X2-1H.$,`)#@`!"AX@2`D.``D*'BAL*@
MX0#`C>7X@<WAT(#-X2)!H.$#3X3A"H"(X=BAS>$"#Z#A","=Y0B@FN``L*OB
M"B"@X?BCS>$`H(3A!+"%X0J`H.$+D*#AT`/-X?B!S>'0A,WA"D"`X0M0@>$$
M@`C@!9`)X(!%'^7P@,WA`("@X=@!S>$C'HWB`%"@XP"`".#0`,'A`#"@XZ*M
MH.$$`)#@!1"AX(.BBN'P!,WAT`#-X02@C>4GD:#A"`"`X0!`H.'0!,WA)H&@
MX0>/B.$,`)#@`!"AX@1`D.``4*'B@L*@X0#`C>7X0,WAT$#-X8[/C>(&#Z#A
M"D"$X=B@S>$$H)K@T$#,X0"PJ^+X0,WA\*3-X0I`H.$(L(GA`*"(X0I@H.$+
M<*#AV*'-X0!0H..DS:#A!H"*X0@`H.'8@\WAA<*,X0#`C>4`@`C@"`"@X87"
MH.$*@*#AV*#-X?ACS>$&@`C@I,V,X7!F'^4,P(WE,,"=Y0:@FN``<*#C"&"`
MX0>PJ^`&`*#A#&":X`!PJ^(``);@`!"GXJ7-H.$$P(WEA,*@X0C`C>7P`\WA
MT*#-X=@`S>$B@:#A`X^(X0"@BN$*`*#AT*/-X2.1H.$";Z#A`*":X`"PJ^(*
M`*#A^*#-X0"PH.,+$*#A!J"(X0BPB>'88\WA"H"@X0N0H.$(H(;A\(/-X="$
MS>$)S8WBH"V@X0J`".`(H*#AT(/-X8$B@N$$((WE"&`&X`EP!^#0@,SA\&3-
MX3QG'^4`<*#C!H"8X`>0J>`(8*#A"7"@X="$S>$8P)WE"H"(X0R@EN"`PJ#A
M`,"-Y0"PI^+08,WA),&@X07/C.$(H)K@`F"&X0#`C>4`L*OB##"@X0:`FN"2
MSXWB`)"KXM"@S.$EP:#A!,"-Y?"$S>$`D*#C"&"@X0EPH.'0@,WA!"^@X:9-
MH.$"@(CA`Y")X0@@H.$),*#AT(/-X?@AS>&'0H3A`H`HX.`G'^4#D"G@"B"2
MX``PH.,+,*/@`J"@X0.PH.'8(,WA!$"-Y2?!H.$(("+@"3`CX/@@S>$X,)WE
M`X":X(8RH.$`,(WE"#"=Y0"0J^(#H)C@T"#-X2"!H.$`L*GB!"""X0)`FN`!
MCXCA(9&@X0`?H.$`4*OB)3Z-X@`0C>4``*#C`!"@X]"@P^'X1<WA!("-Y?@`
MS>'0`,WA`%"@XP0@H.$)$('A`9"@X0@`@.&D':#A"!"-Y0"`H.'8`<WA^(/-
MX04PH.$(`"#@`("@X:P('^4)$"'@"@"0X`&0H.$`$*#C"Q"AX`&PH.$($)WE
MA1*!X=!$S>$($(WE,!"=Y0A`).`)4"7@`8"0X/!`S>&C':#A#!"-Y0`0G>4`
MD*OB`:"8X-@`S>&"0J#A`+"IX@0`@.$`@)K@)A&@X0"0J^(''X'A`!"-Y03`
MC>4(`*#A\(3-X="`S>$!4*#A!D^@X02`B.$%D(GA"$"@X0E0H.&6'XWBV(/-
MX="@P>'P0\WA!(`HX&!)'^4`4*#C"D"4X`M0I>`$H*#A!;"@X=A%S>$`$*#C
M&,"=Y:!MH.$(0"3@@6*&X02`H.$,0)K@@,*@X01@C>4`P(WE`%"KX@B@E.``
ML*7BT$#-X2+!H.$#SXSA!D"$X0#`C>4,<*#A)LZ-X@2`FN``D*OB`F^@X="@
MS.$`(*#C(\&@X0`PH.,$P(WE^"#-X=`@S>$(0*#A^(7-X="#S>$&((+A`F"@
MX0*`*.`',(/A$"H?Y0-PH.&D/:#A"B"2X`@PC>4`,*#C"S"CX`!0H./X8<WA
M`["@X0@PG>4"H*#AA3*#X0@PC>70),WA!Y`IX(1BH.$(("+@"3`CX"'!H.'P
M(,WA.#"=Y03`C>4#@)K@I3V@X0PPC>4`,)WE`)"KX@.@F.#8(,WA(#&@X0$_
M@^$&((+A`#"-Y0"PJ>("@)K@`)"KX@!OH.'0`,WA`W"@X9H_C>(((*#A\(3-
MX:C-H.'8@<WAT*##X08`@.$`,*#C!Q"!X0&0*>#X`\WA@Q*,X0@0C>4`@"C@
MV`7-X>QJ'^4`<*#C"``@X`D0(>`*8);@\`#-X3`0G>4+<*?@`8"6X*,=H.$,
M$(WE`!"=Y0"0I^(!H)C@V`#-X8)BH.$D$:#A!@"`X04?@>$`L*GB)<&@X0"`
MFN``D*OB`!"-Y03`C>4!<*#A!&^@X2<>C>+00,WA^(7-X0"0H./0H,'A"`"@
MX0D0H.&HS:#AV(/-X09`A.$'4(7A!(`HX/!#S>'01,WA@<*,X91K'^4(P(WE
M&,"=Y0I@EN`(0"3@`'"@XPMPI^`$@*#A#$"6X`!0I^*AS:#A"*"4X"*!H.$#
MCXCA(Y&@X0S`C>4"/Z#A`+"EX@`@H./80,WA`#"-Y0`PH.,$@(WE^"#-X=`@
MS>&`8J#A!D"$X01@FN`(((+A"3"#X9[/C>+0@\WA`'"KX@9`H.'0H,SA\&3-
MX0*`*.`"8*#A+"P?Y0-PH.&D/:#A"#"-Y0H@DN``,*#C"S"CX`!0H.,#L*#A
M"#"=Y0*@H.&%,H/A"#"-Y=@ES>$'D"G@^&'-X0@@(N`),"/@A&*@X?`@S>$X
M,)WE(<&@X0.`FN"E/:#A##"-Y0`PG>4`D*OB`Z"8X-@@S>$@,:#A`3^#X08@
M@N$`L*GB`H":X``PC>4`D*OB!,"-Y0-PH.$`;Z#A"CV-XM``S>'XA<WA`)"@
MX]"@P^$((*#A"3"@X:C-H.'8@<WA!@"`X0<0@>$!D"G@^`/-X8,2C.$`@"C@
M"!"-Y=`$S>$,;1_E`'"@XP@`(.`)$"'@"F"6X/``S>$P$)WE"W"GX`&`EN"C
M':#A#!"-Y0`0G>4`D*?B`:"8X-@`S>$D$:#A!1^!X8)BH.$&`(#A`7"@X0`0
MC>6B'XWB`+"IXB7!H.$`@)K@`)"KXM"@P>$$P(WE!&^@X=!`S>$(`*#A\(3-
MX09`A.$'4(7A!("@X060H.'80\WA\(/-X0!0H.,(0"3@!("@X;!(G^4`$*#C
M"D"4X`M0I>`$H*#A!;"@X:#-H.'81<WA@<*,X0C`C>48P)WE"$`DX`2`H.$,
M0)K@H<V@X0S`C>4`4*OB"*"4X`"PI>+80,WA(L&@X0//C.&`8J#A`,"-Y09`
MA.$,<*#A*<Z-X@2`FN``D*OB`F^@X="@S.$`(*#C(\&@X0`PH.,$P(WE^"#-
MX=`@S>$(0*#A^(7-X="#S>$&((+A`F"@X0*`*.`',(/A`"B?Y0-PH.&D/:#A
M"#"-Y0H@DN``,*#C"S"CX`!0H.,#L*#A"#"=Y0*@H.&%,H/A"#"-Y=`DS>$'
MD"G@^&'-X0@@(N`),"/@A&*@X?`@S>$X,)WE(<&@X0.`FN"E/:#A##"-Y0`P
MG>4`D*OB`Z"8X-@@S>$@,:#A`3^#X08@@N$`L*GB`#"-Y0*`FN`$P(WE`)"K
MX@-PH.$`;Z#AIC^-XM``S>'0H,/A"""@X:C-H.'PA,WAV('-X0`PH.,&`(#A
M!Q"!X0&0*>#X`\WA@Q*,X0@0C>4`@"C@V`7-X21GG^4`<*#C"``@X`D0(>`*
M8);@\`#-X3`0G>4+<*?@`8"6X*,=H.$,$(WE`!"=Y0"0I^(!H)C@V`#-X8)B
MH.$D$:#A!@"`X04?@>$`L*GB)<&@X0"`FN``$(WE!,"-Y0"0J^(!<*#A!&^@
MX2H>C>+00,WA^(7-X0"0H./0H,'A"`"@X0D0H.&HS:#AV(/-X09`A.$'4(7A
M!(`HX/!#S>'01,WA@<*,X7QFG^4(P(WE&,"=Y0I@EN`(0"3@`'"@XPMPI^`$
M@*#A#$"6X`!0I^((H)3@(H&@X0./B.&AS:#A(Y&@X0(_H.$,P(WE`#"-Y0`@
MH.,`,*#C`+"EX@2`C>780,WA^"#-X=`@S>&`8J#A!D"$X01@FN`(((+A"3"#
MX:K/C>+0@\WA`'"KX@9`H.'0H,SA\&3-X0*`*.`"8*#AY"6?Y0-PH.&D/:#A
M"#"-Y0H@DN``,*#C"S"CX`!0H.,#L*#A"#"=Y0*@H.&%,H/A"#"-Y=@ES>$'
MD"G@^&'-X0@@(N`),"/@A&*@X?`@S>$X,)WE(<&@X0.`FN"E/:#A##"-Y0`P
MG>4`D*OB`Z"8X-@@S>$@,:#A`3^#X08@@N$`L*GB`H":X``PC>4$P(WE`)"K
MX@-PH.$`;Z#A*SZ-XM``S>'XA<WA`)"@X]"@P^$((*#A"3"@X:C-H.'8@<WA
M!@"`X0<0@>$!D"G@^`/-X8,2C.$($(WE`(`HX-`$S>$$99_E`'"@XP@`(.`)
M$"'@"F"6X/``S>$P$)WE"W"GX`&`EN"C':#A#!"-Y0`0G>4`D*?B`:"8X-@`
MS>$D$:#A!1^!X27!H.$`$(WE@F*@X03`C>4&`(#A!&^@X=!`S>$`L*GB`(":
MX`"0J^(!<*#A!D"$X0=0A>$(`*#A\(3-X02`H.$%D*#AV$/-X:X?C>+P@\WA
MT*#!X0A`).`$@*#A9$2?Y0!0H.,*0)3@`!"@XPM0I>`$H*#A!;"@X:#-H.'8
M1<WA@<*,X0C`C>48P)WE"$`DX`2`H.$,0)K@H<V@X0!0J^(,P(WE"*"4X`"P
MI>+80,WA@&*@X2+!H.$#SXSA!D"$X02`FN`,<*#A`,"-Y0O-C>(`D*OBT*#,
MX2/!H.$";Z#A^(7-X03`C>70(,WA"$"@X:C-H.'0@\WA`%"@XP8@@N$',(/A
M`Y`IX/@AS>&%,HSA"#"-Y0*`*.#0),WAI&.?Y0!PH.,(("+@"3`CX`I@EN#P
M(,WA.#"=Y0MPI^`#@);@I3V@X0PPC>4`,)WE`)"GX@.@F.#8(,WAA&*@X0"P
MJ>(&((+A`H":X"`QH.$`D*OB`3^#X0`PC>4#<*#A(<&@X;(_C>($P(WE^(/-
MX0"0H./0H,/A"""@X0DPH.'0@,WA`&^@X3#`G>4&@(CA!Y")X0A@H.$)<*#A
MV('-X?A@S>$`<*#C!H`HX/ABG^6B#:#A"F"6X`MPI^`&H*#A!["@X=AES>&#
M`H#A!`"-Y0A@)N`&@*#A#&":X(+"H.$`P(WE`'"KX@B@EN``L*?BT&#-X22!
MH.$%CXCA`&"&X08`FN``$*OB!("-Y?`$S>$`$*#C`7"@X00?H.$`$(WE`&"@
MX=``S>$ED:#A+<Z-X@@`@.$)$('AV(#-X="@S.'P`\WA`(`HX%P"G^4!D"G@
M"@"0X``0H.,+$*'@`*"@X0&PH.'8`\WAIDV@X8="A.$(`"#@"1`AX`1`C>7X
M`\WA&!"=Y0&`FN"&$J#A`!"-Y3@0G>4`D*OB`:"8X-``S>$`L*GB(H&@X00`
M@.$`0)K@`%"KX@./B.$CD:#AMA^-X@(_H.$$@(WE`#"-Y?A#S>$`4*#C!`"@
MX="@P>$%$*#AT$#-X0C`G>6@+:#A"$"$X0E0A>&P@9_E^$'-X0J`F.`,H)C@
MT$/-X=B!S>&!(H+A@,*@X0A`).#0A,WA!""-Y0#`C>4$@"C@"(":X`B@H.'0
M@,WA`)"@XR9!H.$"@(CA"*":X`J`H.$'3X3A\(#-X0"`H.,`D*#C"*"@X0FP
MH.$&+Z#A^*#-X0*@A.'00,WA-"&?Y3#`G>6%,J#A##"-Y2X^C>*DC:#AT&##
MX86"B.'80\WA`F"6X-@AS>$,8);@#("-Y0H@(N`"0"3@!""@X=!`S>$!/Z#A
MA,*@X0C`C>4"0);@!&"@X=A`S>$`4*#C!9"@X0A`A.$$(*#A`$"@XP2`H.$@
M0:#A`4^$X0`?H.'X@,WA##"-Y0@0C>4,0(WEV(#-X0)@EN#0(<WA!("(X=!%
MS>$8$)WE!B"2X`%`E.``4*7BV`3-X?A`S>'00,WA`#"@X]ABS>$`0)3@`5"E
MX/`@SN$$`*#A!1"@X=`BS>%8,)_E\`#-X0I@EN#80,WA#J"@X=``S>'LXIWE
M`,"3Y0@@DN``4*#C`!"@XP!PH.,`,*#C#`!>X?!"RN$*X*#A^`#*X?AARN'P
M(<KA`0``&KW?C>+PC[WHU>[_Z];!8LI`P0(```!0XQ[_+P'X0RWIK#"?Y0"0
MD^4``%GC)@``"@!0T.4]`%7C``!5$P%0H!,`4*`#$P``&@!`F>4``%3C#@``
M"@&`H.$`<*#A"6"@X00`H.$'$*#A!2"@X4SO_^L``%#C`@``&@4PU.<]`%/C
M"P``"@1`MN4``%3C\___&@0`H.'X@[WH`%"@X0$P]>4]`%/C``!3$_O__QH%
M4&#@Y/__Z@9@:>`!`(7B1F&@X0!@B.4``(3@^(.]Z`D`H.'X@[WH.,$"`'!`
M+>D`0*#A<&"?Y7!0G^4(T$WB`#"6Y00PC>4$`*#A#1"@X<3__^L``%#C#```
M"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""SY0``4N,$(`/E
M^___&NW__^H$()WE`#"6Y0,`4N$!```:"-"-XG"`O>B"[O_K0,$"`#C!`@#P
M3RWI`4"@X0`@T>7L49_E%-!-XCT`4N,!0($"`#"5Y0!@H.$$`*#A##"-Y;/N
M_^L($(WB`'"@X08`H.&<___K`*!0XCT```JL[O_K``!7X30``)H(@)WEI)&?
MY0B!H.$`$-;E/0!1XP``41,!$*`3`!"@`P4```H&$*#A`3#QY3T`4^,``%,3
M^___&@$09N`"`(?B`0"`X`!PF>6%[O_K7#&?Y0``4.,(`(?G4```"@`@D^4(
M$)WE`##6Y0%@AN(!$9+G``!3XST`4Q,`,,'E!@``"@$@@>(!,-;D`A"@X0``
M4^,]`%,3`3#"Y/G__QH!(*#A/3"@XP`PP>4!,-3D``!3XP$PXN7[__\:``"@
MXPP@G>4`,)7E`P!2X38``!H4T(WB\(^]Z`$@2N(!,-3D``!3XP$PXN7[__\:
M\O__ZKR0G^4`L)GE`"";Y0``4N,D```*"S"@X00@L^4!H(KB``!2X_O__QH"
M$(KB`1&@X9`PG^4`()/E``!2XPH```H+`*#A)^[_ZP``4.,``(GE%P``"@J!
MH.$!,(KB`""@XP,A@.<(H(WEK/__Z@$@H.,!`*#A`""#Y3[N_^L`,%#B!#"-
MY0H```H*@:#A"Q"@X0@@H.'L[?_K!#"=Y0,`H.$`,(GEZ___Z@*@H.$($*#C
MWO__Z@``X./$___J`.[_ZT#!`@`XP0(`:,$"`/!!+>EXT$WB)%&?Y0!P4.(`
M,)7E=#"-Y0(```H`,-?E``!3XP4``!IT()WE`#"5Y0,`4N$]```:>-"-XO"!
MO>@3[O_K`&!0XO;__PH&`*#A:>[_ZP``4.,D```*$R#0Y2X`4N,F```*$T"`
MX@<`H.$?[O_K`("@X00`H.$<[O_K``"(X`(`@.('[O_K`1"@XP`@X..<,)_E
M!$"-Y0!PC>4`@*#A(>[_ZP@0H.$#`*#C"""-XESN_^L!`'#C"`"@X0,```H8
M,)WE#SH#X@$)4^,4```*S>W_ZP@`H.&J[?_K!@"@X43N_^L``%#CVO__&@8`
MH.%;[O_K!P"@X;'M_^O(___J%"#0Y0``4N/.__\*+@!2X]/__QH5(-#E``!2
MX\G__PK/___JM/__Z^G__^JP[?_K0,$"`(!Y`0!P0"WI"$&?Y0``E.5)[O_K
M@#"0Y0``E.4$8)/E1>[_ZV50T.4``)3E0N[_ZW]0!>($,)#EL#'3X8,[H.$C
M6(7ALE#&X0``E.4Z[O_K@#"0Y0``E.4$4)/E-N[_Z[00G^4`(*#CW.W_ZQP`
MA>4``)3E,.[_ZX`PD.4``)3E!%"3Y2SN_^O@-)#E``"4Y2`PA>4H[O_K@#"0
MY0``E.4$4)/E).[_Z_PPD.4``%/C`P``"@``E.4?[O_K_#"0Y7`PD^4D,(7E
M``"4Y1KN_^L`4*#C@#"0Y0``E.4$,)/E*%"#Y13N_^N`,)#E``"4Y00PD^48
M4(/E#^[_ZX`PD.4``)3E!$"3Y0ON_^L8,I#E+#"$Y7"`O>A(P0(`D'P!`#A`
M+>D`4*#A;$"?Y0``E.4![O_K!1"@X4(O@.(#`*#C]^W_ZP``4.,!```*``"@
MXSB`O>@``)3E]^W_ZQ@QD.4/.@/B`0E3XP4```H``)3E\>W_ZQ@QD.4/.@/B
M"@I3X_'__QH%`*#A`A"@X\#M_^L0#V_AH`*@X3B`O>A(P0(`\$`MZ0':3>+,
M4)_E#-!-X@'*C>(`,)7E!,",X@!@H.$!<*#AM`"?Y000C>*P()_E`#",Y4OM
M_^L``%#C'@``V@%`0.((,(WB!,"#X`0@7.4``%+C%@``"@!`H.$$`(WB+Q"@
MXP0@H.&>[?_K``!0XQ$```IL,)_E``"3Y<;M_^L&$*#A!""-X@0PH.&G[?_K
M`3J-X@0P@^(`()/E`#"5Y0,`4N$+```:`=J-X@S0C>+P@+WH``!4X^?__QHD
M,)_E``"3Y;3M_^L&$*#A!R"@X2'M_^OM___J$.W_ZT#!`@"(>0$`_P\``$C!
M`@`<,)_E$$`MZ0``D^6G[?_K$!"?Y1`@G^40,)_E$$"]Z%KM_^I(P0(`F'D!
M`!`6`0`$>0$`$$`MZ0C03>(T0)_E``"4Y9GM_^OL___K``"4Y9;M_^L@,)_E
M`""@XP0@C>4`,(WE%!"?Y10@G^5?[?_K"-"-XA"`O>A(P0(`D'P!`+1Y`0`,
M=`$`<$`MZ0+:3>+,8)_E(-!-X@(JC>(`,);E'"""X@`P@N4:[?_KM#"?Y10@
MC>((((WE!#"-Y0$0H..D()_EI#"?Y0``C>4(`)WE)>W_ZP``4.,<``"Z`3J-
MXB`P@^((,$/B"`"=Y0,0H.$!*J#C##"-Y=_L_^L`4%#B$@``N@$`A>+V[/_K
M`$!0XA````H,$)WE!2"@X:_L_^L$`*#A`#"@XP4PQ.<".HWB'#"#X@`@D^4`
M,);E`P!2X08``!H"VHWB(-"-XG"`O>@``*#C]/__Z@0`H.'R___JL^S_ZT#!
M`@#8>0$``1```,QY`0##___J\$\MZ0':3>*X,9_E'-!-X@$JC>(`,)/E%"""
MX@!`H.$!8*#AH`&?Y1`0C>(`,(+ES?W_ZR\0H.,`4*#A!`"@X>+L_^L``%#C
M#0``"GP!G^4$$*#A%_[_ZP0`H.$!.HWB%#"#X@`@D^58,9_E`#"3Y0,`4N%2
M```:`=J-XAS0C>+PC[WH!`"@X<KL_^M`$9_E`)"@X08`H.'_[/_K`+!0XNG_
M_PHL<9_E+(&?Y2RAG^4L89_E`##;Y0``4^,'L*`!``!5XP0```H%`*#A"Q"@
MX4_L_^L``%#C*```"@L`H.&T[/_K`#"+X`$P4^4O`%/C!P``&@$P0.(#,(O@
M`,"@XP#`P^4!$'/E`0!`XB\`4>/Z__\*`3")X@``@^`(`%#AR?__R@$0H.,!
M*J#CM#"?Y0"PC>4$H(WE"$"-Y10`C>*K[/_K``"6Y?KL_^L4$(WB0B^`X@,`
MH./D[/_K``!0XP4``!H``);E\NS_ZQ@QD.4/.@/B`@E3XP8```H``*#C3!"?
MY<3L_^L``%#C`+"@X<?__QJL___J%`"-X@$0H..Z[/_K``!0X_/__QH4$(WB
M&`"?Y;_]_^L4`(WBDNS_ZZ7__^H\[/_K0,$"`.!Y`0#L>0$`_'D!`-QY`0#_
M#P``"'H!`$C!`@``>@$``##0Y0``4^,>_R\!`2"`XB\`4^,"`*`!`3#2Y```
M4^/Z__\:'O\OX3A`+>D`0%#B*P``"@!0U.4``%7C*```"F'L_^L!`$#B`#"$
MX`,`5.$+```J`"#4YR\`4N,I```:`2!#X@,``.H`$-+E`2!"XB\`4>,C```:
M!`!2X0(PH.'X__\:`P!4X1,```H!,$/B`P``Z@`0T^4!,$/B+P!1XP(``!H#
M`%3A`R"@X?C__SH"(&3@`C""X@$*4^,/``"*!!"@X0$@@N(!.J#C:`"?Y?OK
M_^M@`)_E.("]Z"\`5>,2```:`@"@XR7L_^L``%#C`@``"BXPH..P,,#A.("]
MZ```H.,X@+WH`2!#X@,``.H`$-+E`2!"XB\`4>/:__\*`@!4X0(PH.'X__\Z
MU/__Z@@`G^4X0+WH..S_ZFS!`@`(>@$`,$`MZ3303>)0X9_E","-XDQ!G^4/
M`+[H`%"4Y0\`K.@/`+[H+%"-Y0#@GN4/`*SH,`&?Y;#@S.$P_?_K*`&?Y2[]
M_^LD`9_E+/W_ZR`!G^4J_?_K'`&?Y2C]_^L8`9_E)OW_ZQ0!G^4D_?_K$`&?
MY2+]_^L,`9_E(/W_ZP@!G^4>_?_K!`&?Y1S]_^L``9_E&OW_Z_P`G^48_?_K
M!!"-XO0`G^7D_/_K`!!0X@$```K0`)_E,_W_ZP00C>+<`)_EW?S_ZP`04.(!
M```*T`"?Y2S]_^L$$(WBR`"?Y=;\_^L`$%#B"@``"I``G^4E_?_K@`"?Y;`0
MG^4B_?_K+""=Y0`PE.4#`%+A$P``&C30C>(P@+WH!!"-XI``G^7&_/_K`!!0
MX@(```I4`)_E%?W_Z^[__^H9`(WB=!"?Y0H@H.,A[/_K``!0X^C__QHC$(WB
M+`"?Y0O]_^OD___JBNO_ZQ!Y`0!`P0(`#'H!`!AZ`0`@>@$`+'H!`#1Z`0!$
M>@$`X'D!`%!Z`0!<>@$`:'H!`.QY`0!T>@$`@'H!`(QZ`0"@>@$`M'H!`,!Z
M`0#P>@$`T'H!`.1Z`0`P0"WI#-!-XF!0G^5@0)_E``"5Y0`PE.4!`'#C!#"-
MY04```H$()WE`#"4Y0,`4N$-```:#-"-XC"`O>@T`)_E#1"@X8[\_^L``%#C
M!```"@``T.4``%#C,`!0$P$`H!,``*`#``"%Y>W__^I8Z__K+,$"`$#!`@!0
M>@$`"$`MZ3+K_^LKZ__K``!0XP``D!4(@+WH\$<MZ0!PH.'TX)_E.-!-XAC`
MC>(/`+[HZ("?Y0\`K.@'`)[H&$"=Y0`PF.4``%3C!P",Z#0PC>47```*R)"?
MY1A0C>(&``#J!Q"@X0[K_^L``%#C%@``"@1`M>4``%3C#0``"@0`H.$4$(WB
M7_S_ZP!@4.("```*`##6Y0``4^/P__\:!`"@X0<0H.&J_/_K!$"UY0``5./Q
M__\:-""=Y0`PF.4#`%+A%```&CC0C>+PA[WH!P"@X5_K_^L`H*#A!@"@X5SK
M_^L``(K@`@"`XD?K_^N``HWH"&"-Y0$0H.,`(.#C)#"?Y0"@H.%AZ__K!`"@
MX0H0H.&/_/_KU?__Z@[K_^LT>0$`0,$"`/QY`0``>@$`?#F?Y?!/+>D`4*#A
M@=Q-X@<`D^@\T$WB0,"-X@Q`@^('`(SH),"#X@\`M.A8X(WB3&"-X@\`KN@#
M`)3H1#F?Y0,`CN@'`)SH@<R-X@`PD^4TP(SB!P"&Z#P0C>(H"9_E`#",Y1S\
M_^L`0%#B`@``"@`PU.4``%/C`0$`&I3__^L`0%#B3&"-`D<```H$`*#A).O_
MZX``H.$!`(#B#^O_ZP`PU.4``%/C`("@X0!@H!$)```*`#"-Y08`H.',.)_E
M`1"@XP`@X.,EZ__K`3#TY0)@AN(``%/C]?__&E@`G>4``%#C6$"-$@,``!H0
M``#J!`"TY0``4.,-```*/!"-XO7[_^L`8%#B^/__"@`PUN4``%/C]?__"EO]
M_^L``%#C\O__"@8`H.$3Z__K`)!0XBD``!I`0)WE``!4XR4```H`,-3E``!3
MXP%@H!,)```:(```ZDX_C>(&,8/@^$`3Y0``5.,;```*`##4Y0%@AN(``%/C
M%P``"@0`H.%"_?_K``!0X_+__PH$`*#A^NK_ZP``4./N__\*`)"@X0X``.KU
MZO_K``!0X[P``!H$`);D``!0X[8```H\$(WBQOO_ZP`P4.+X__\*`##3Y0``
M4^/U__\*\?__Z@"0H.,)`*#AT.K_ZZAWG^4`0*#A"`"@X<SJ_^L``(3@`4N`
MX@1`A.($`*#AM>K_ZX@WG^4!$*#C"#"-Y0`@X.-\-Y_E`)"-Y0R`C>4$<(WE
M`&"@X<SJ_^L&`*#A!QV@X]7J_^L!`'#C&@``"E2'G^4``)CE%>O_ZP80H.%"
M+X#B`P"@XPOK_^L``%#C'P``"C0GG^4`,)7E`1"@XP!@C>4``)+E)">?Y=7J
M_^L``*#C@3R-XC0P@^(`()/E[#:?Y0`PD^4#`%+AM@$`&H'<C>(\T(WB\(^]
MZ*CJ_^L`()#E$0!2X^#__PK<%I_E`#"5Y0!@C>4``)'E!""-Y0$0H./,)I_E
MONK_ZP``H./G___J``"8Y>WJ_^L8,9#E#SH#X@$)4^/9__\:``"8Y>?J_^L@
MD9#E)>K_ZP``6>'3__\:``"8Y>'J_^L8,9#E@SN@X0X"4^/-__\:!`"@X6GJ
M_^L\$(WB`$"@X6@&G^5D^__K``!0XXD!``H`@)7EB.K_ZP`0H.$(`*#A@OW_
MZP"`4.*"`0`*"`"@X6SJ_^L#`%#C`)"@X0L``-H$`$#B``"(X"06G^7\Z?_K
M``!0XP4``!H$`%GC,0$`"@F0B.`%,%GE+P!3XRT!``JH_O_K`!!0X@0``!H(
M`*#A0^K_ZP`P4.(@,(WE-0``&N`5G^7@!9_EDOO_ZTOJ_^O8E9_EP`"-Z`R0
MC>4!$*#C`"#@X\@UG^4`@*#C"`"-Y00`H.%6ZO_K#@``ZE'J_^L`,)#E$0!3
MXQ```!H[ZO_K`8"(X@R`C>7``(WH$)"-Y04@H.$!$*#CB#6?Y0@`C>4$`*#A
M1NK_ZP0`H.$'':#C3^K_ZP$`<.,`4*#AZO__"@8`H.'5Z?_K!!"@X1@%G^5L
M^__K!`"@X9O^_^L$`*#A@/__ZIC^_^L$`*#A.NK_ZWS__^HP19_E#0"@X_[^
M_^H`0*#A^/[_Z@)0H.,`,.#C$2#@XP!0C>7YZ?_K31^-XB``G>4&(*#CL^G_
MZS0QW>4``%/C`@``&C4QW>5#`%/C`P$`"@!0H.,`(*#C`#"@XP!0C>4@`)WE
MZ>G_Z\RDG^7,!)_E`!"@X\@DG^4`L*#C`#"@X_`'S>&\A)_EO`2?Y?BHS>&H
MH(WB^"?-X0"0H.,`(*#C`#"@XP`0H.,D0(WE"D"@X>A0C>7PB,WA\`G-X?@I
MS>'P*LWA*&"-Y2QPC>4@`)WE31^-X@(IH..*Z?_K`%!0XE0``-K8*<WAA6&@
MX0"0H.,"@);@"0!3X0@`4@$%`*#AQ1^@X=`JS>$!``":`2"2X@`PH^*@SJ#A
M@<&,X:$>H.$8P(WE'!"-Y=BAS>'H`)WE^(G-X0*@FN`#L*O@"B"@X0LPH.$`
M`%#C\"K-X3<```I`,&#B`P!5X0.`H*$%@*"Q<#"-XC@`@.(``(/@"""@X4T?
MC>)RZ?_KZ#"=Y0,PB.!``%/CZ#"-Y<___QI-/XWB<`"-X@50:.`(@(/@`.O_
MZS\`5>,:``#:0+"(X@60H.$$H*#A0$!+X@K@H.$``)3E!!"4Y0@@E.4,,)3E
M#L"@X1!`A.(+`%3A#P"LZ`S@H.'U__\:0)!)XG``C>+LZO_K/P!9XT"PA.+M
M___*0%!%X@I`H.$E,Z#A`2"#X@-31>`"@XC@"!"@X00`H.$%(*#A2#"@XW#I
M_^OH4(WEIO__ZDV/C>+9___J(`"-XM$`D.CJZ?_KF%"=Y4X_C>)_$.#CI2&@
MX3\@`N(",(/@`0""XC@`4..0$$/E.0""XG`PC>*@@)WE``"#X&,``,HW(&+B
M`!"@XZ#I_^LHZ*#A*,2@X24<H.$E**#A)32@X2B<H.%P`(WBXX#-Y>=0S>7@
MD,WEX>#-Y>+`S>7D$,WEY2#-Y>8PS>6VZO_K<."=Y7@`G>6`$)WE+HB@X2X\
MH.'WX,WE+N2@X?;@S>4@[*#AB""=Y?L`S>7XX,WE(.B@X2`$H.&0P)WE^@#-
MY2$,H.'YX,WE_`#-Y4[OC>(A"*#A,9!.XO\0S>4B[*#A(12@X?T`S>4#(<WE
M(@B@X2(DH.%"KXWB_A#-Y0$!S>4L'*#A+`B@X0(AS>4L)*#A]8#-Y0I0H.'T
M,,WE]("-X@#AS>4'P<WE!!'-Y04!S>4&(<WE````Z@$P^.4`,(WE!0"@X0$0
MH.,`(.#C8#&?Y4SI_^L)`%CA`E"%XO7__QI\,9_E`,"@XPPPC>7`!(WH!`"@
MX0$0H.,`(.#CA#&?Y3#!S>4_Z?_K_?[_Z@10E>4``%7CSO[_"@4`H.$JZ?_K
M`P!0X\K^_YH$`$#B``"%X%01G^6[Z/_K``!0XP6`H`'#_O_J/R!BX@`0H.,\
MZ?_K<`"-XF#J_^L`,*#CJ#"-Y:PPC>6P,(WEM#"-Y;@PC>6\,(WEP#"-Y<0P
MC>7(,(WES#"-Y=`PC>74,(WEV#"-Y=PPC>6)___J-C'=Y4$`4^/X_O\:-S'=
MY4,`4^/U_O\:.#'=Y4@`4^/R_O\:.3'=Y44`4^/O_O\:`%"-Y2!0G>4`,.#C
M!0"@X3D@X./9Z/_K31^-X@4`H.$I(*#CD^C_ZVPPG^5-+XWB"""-Y0PPC>7`
M`(WH!`"@X0$0H.,`(.#C<#"?Y?OH_^NY_O_J`("5Y7K^_^JIZ/_K4'D!`$#!
M`@#@>0$`_'H!``AZ`0`0>P$`!'L!`$C!`@!0P0(`F'L!`!A[`0#D?`$`5'L!
M`/!Z`0!0>@$`D'P!`'1[`0"$>P$`]'H!`'94,A`!(T5GB:O-[_[<NICPX=+#
M9'L!`%Q[`0"`,Y_E\$\MZ0S03>)X<Y_E`#"3Y0``E^4$,(WE)NG_ZP$PH.,-
M$*#A83#`Y5P#G^6N^?_K``!0XP(```H`,-#E,0!3XX8```J9_/_K``"7Y1GI
M_^LX$Y_E`2"@XPLPH..IZ/_K+&.?Y0``4.,N```*$""0Y?0_%N4!`%/C&("2
MY2D``-H`DY_E`%"@XP%`H.,)``#J$!"2Y0H`H.$]Z/_K]#\6Y0``4.,<```:
M`4"$X@0`4^$!4(7B&```V@``E^7]Z/_K"!"@X04@H.$`,*#CU>C_ZP"P4.(/
M```*`"";Y;0RG^7P'Q;E"`"2Y0`P`^`!"U/C!*&1Y^7__PH``)GE[>C_ZP`0
MF^4`(*#C`C"@XV+H_^L`$*#AWO__ZO0_%N4!($/B!0!2X4$```H``)?EX>C_
MZV02G^4!(*#C`S"@XW'H_^M`4I_E`$!0X@H```H``)7EV.C_ZQ`PE.5`(I_E
M`!"3Y43H_^L0,)3E`#"3Y0@PD^4!!1/C<P``&@``E^7-Z/_K'!*?Y0$@H.,#
M,*#C7>C_Z_!!G^4`4%#B"@``"@0"G^4-$*#A4/G_ZP"`4.(``)3E3```"K_H
M_^L0,)7E"""@X0`0D^4KZ/_K``"7Y;GH_^L`,*#C#1"@X:B1G^6P@9_E83#`
MY<`!G^4_^?_K``!0XP!`H.'L#P;E'```"@<=H.-GZ/_K`3"`XA$`4.,!`%,3
M50``BF@QG^4$()WE`#"3Y0,`4N%/```:#-"-XO"/O>@!`%/CN___V@%`H.,`
M`)?EG.C_ZP@0H.'CY__K]#\6Y0%`A.($`%/A]___RK'__^H!,-#E``!3XW;_
M_PIT___J\`\8Y>7\_^L``%#C[`\(Y38```H0()7E"#&?Y0`@DN4($)+E`3`#
MX`$+4^,A```:$`"2Y?!/%N4$$*#AT.?_ZQ`PE>7<()_E`$"4Y0#`D^4(,)SE
M`R`"X`$+4N,`8*#A"P``&A`@G.4$$*#A!C"@X<@`G^4EZ/_K<NC_ZQ`@E>7P
M/Q;E``"2Y0`0D^6&^O_KL/__Z@``E^5JZ/_K$!"5Y0`@H.,",*#C`!"1Y=[G
M_^L`(*#AZ___Z@``F>5AZ/_K$!"5Y00@H.$",*#C`!"1Y=7G_^O6___J``"5
MY5GH_^L0,)3E`!"3Y1WH_^N%___J3`"?Y07H_^NSY__K\!\8Y0`PH.$$(*#A
M`!"1Y30`G^7^Y__K0,$"`$C!`@`T>@$`['L!`&#A`@``!"``]'L!`/A[`0``
M?`$`['D!`.!Y`0`H?`$`!'P!`%!\`0`X0"WI`%"@X7+[_^L`,-#E`$"@X0``
M4^,%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:'/S_ZP``4.,``%43.("]
M"``PU>4``%/C.("]"`0`H.$4$)_E6^?_ZP``5.$X@+T8!0"@X3A`O>B%^?_J
M$'L!`!!`+>DD0)_E``"4Y1WH_^L`$.#CG>?_ZP``E.49Z/_K#!"?Y0`@H.,0
M0+WH`.C_ZDC!`@"07P$`##"?Y0,PC^```%/C`#"3%7+G_^JD2`$`^$,MZ0!P
MH.%,8)_E3%"?Y09@C^`%4(_@!F!EX`&`H.$"D*#A+^?_ZT9AL.'X@[T(!%!%
MX@!`H.,!0(3B!#"UY0<`H.$($*#A"2"@X3/_+^$&`%3A]___&OB#O>@X1@$`
M,$8!`![_+^$(0"WI"("]Z`$``@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(`````#$?`$`U'P!`-Q\`0#D?`$`['P!``!]
M`0``````O'P!`-QY`0``````M'H!`+AZ`0"P?`$`Y'D!`+A\`0``````G'P!
M`*1\`0``````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C
M+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H`
M```E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]!4D=#`````%!!4E]!
M4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(`
M``!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@````!005)?0TQ%04X]```Q````4UE35$5-```E,#)X`````"5S)7,E<R5S
M`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``<&%R;``````N<&%R`````"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P`````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!!
M4D=6`````!@```!P97)L`````#````!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`
M````55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!,1%],24)205)9
M7U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`````1%E,1%],24)205)97U!!
M5$@```!32$Q)0E]0051(``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P
M,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@
M)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X
M:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@
M>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6
M>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS
M92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!
M4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM
M>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO
M(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU3
M5VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E
M=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S
M+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M]
M.PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?
M1D@I.PIM>2`D8G5F.PIS965K(%]&2"P@+3@L(#(["G)E860@7T9(+"`D8G5F
M+"`X.PIL87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E:R!?
M1D@L("TQ,BP@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M,3(@
M+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D
M8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D
M8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM0
M05)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D
M(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T
M.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D
M=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?
M;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?
M.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN
M960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R
M;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H
M)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E
M*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O
M=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N
M;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P
M87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D
M9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D
M<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O
M(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A
M<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@
M:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P
M-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]7
M4D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE
M("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_
M(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N
M9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B
M4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G
M:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M
M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD
M+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!S;W)T('L*;&5N9W1H*"1B
M*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA+T)31%!!3B\*?2!G<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@+64@
M)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD7WTK
M*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER
M("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%
M7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I
M.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:
M(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L
M<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO
M:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO
M<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE
M.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S
M92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA
M;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#
M;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*
M?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&
M24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H
M)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I
M9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O
M=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H
M85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\
M(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O
M=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@
M;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*
M)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<
M;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O
M<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@
M)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY
M("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@
M+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O
M9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F
M.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H
M85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\
M(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@
M:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L
M("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?
M9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M
M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.
M?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*
M?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I
M;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE
M*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6
M>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA
M;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N
M("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N
M("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`(&+_?P$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````@'`$`^!L!````
M```!`````0````$````%`@```0```!`"```!````&@(```$```!I`@```0``
M`+P#```!````X@,```P```!X%0$`#0```/AX`0`9````W+X"`!L````$````
M&@```."^`@`<````!````/7^_V^T`0$`!0```'0,`0`&````=`4!``H```!B
M!0``"P```!`````5``````````,`````P`(``@```"@"```4````$0```!<`
M``!0$P$`$0```!@3`0`2````.````!,````(````_O__;[@2`0#___]O`P``
M`/#__V_6$0$`````````````````````````````````````````````````
M````````````````Z+X"````````````A!4!`(05`0"$%0$`A!4!`(05`0"$
M%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05
M`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!
M`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`
MA!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$
M%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05
M`0"$%0$`A!4!`(05`0"$%0$`A!4!`(05`0"$%0$`````````````````____
M_PQ]`0!'0T,Z("A287-P8FEA;B`T+CDN,2TQ.2D@-"XY+C$`1T-#.B`H4F%S
M<&)I86X@-"XX+C,M,3,I(#0N."XS`$$P````865A8FD``28````%-@`&!@@!
M"0$*`A($$P$4`14!%P,8`1D!&@(;`QP!(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-
M+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R
M`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I
M8G5T97,``````0```(05`0`````````,``0```"4%0$`````````#``!````
MF!4!``````````P``"1A`"1D````````````````````````````````````
M````````````````````"P````$````"````5`$!`%0!```9````````````
M```!`````````!,````'`````@```'`!`0!P`0``(```````````````!```
M```````A````!P````(```"0`0$`D`$``"0```````````````0`````````
M-````/;__V\"````M`$!`+0!``#``P``!0`````````$````!````#X````+
M`````@```'0%`0!T!0````<```8````!````!````!````!&`````P````(`
M``!T#`$`=`P``&(%``````````````$`````````3@```/___V\"````UA$!
M`-81``#@````!0`````````"`````@```%L```#^__]O`@```+@2`0"X$@``
M8`````8````#````!`````````!J````"0````(````8$P$`&!,``#@````%
M``````````0````(````<P````D```!"````4!,!`%`3```H`@``!0````P`
M```$````"````'P````!````!@```'@5`0!X%0``#```````````````!```
M``````!W`````0````8```"$%0$`A!4``%`#``````````````0````$````
M@@````$````&````V!@!`-@8```@8``````````````(`````````(@````!
M````!@```/AX`0#X>```"```````````````!`````````".`````0````(`
M````>0$``'D``!!```````````````0`````````E@````$``'""````$+D!
M`!"Y```(````#0`````````$`````````*$````!`````@```!BY`0`8N0``
M!```````````````!`````````"K````#@````,```#<O@(`W+X```0`````
M``````````0`````````MP````\````#````X+X"`."^```$````````````
M```$`````````,,````!`````P```.2^`@#DO@``!```````````````!```
M``````#(````!@````,```#HO@(`Z+X``!@!```&``````````0````(````
MT0````$````#`````,`"``#````D`0`````````````$````!````-8````!
M`````P```"3!`@`DP0``$```````````````!`````````#<````"`````,`
M```XP0(`-,$``$00``````````````@`````````X0````$````P````````
M`#3!```^```````````````!`````0```.H````#``!P``````````!RP0``
M,0```````````````0`````````!`````P``````````````H\$``/H`````
/``````````$`````````
